@@ -12,13 +12,13 @@ from cloud_governance.gitleaks.gitleaks import GitLeaks
 # os.environ['AWS_DEFAULT_REGION'] = 'us-east-2'
 # os.environ['AWS_DEFAULT_REGION'] = 'all'
 # os.environ['policy'] = 'tag_ec2'
-#os.environ['policy'] = 'zombie_cluster_resource'
-# #os.environ['action'] = 'tag_cluster_resource'
+# os.environ['policy'] = 'zombie_cluster_resource'
+# os.environ['policy'] = 'tag_cluster_resource'
 # os.environ['policy_output'] ='s3://redhat-cloud-governance/logs'
 # os.environ['dry_run'] = 'yes'
 # os.environ['policy'] = 'ebs_unattached'
 # os.environ['resource_name'] = 'ocp-orch-perf'
-#os.environ['resource_name'] = 'ocs-test'
+# os.environ['resource_name'] = 'ocs-test'
 # os.environ['mandatory_tags'] = "{'Owner': 'Eli Battat','Email': 'ebattat@redhat.com','Purpose': 'test'}"
 # os.environ['mandatory_tags'] = ''
 # os.environ['policy'] = 'gitleaks'
@@ -75,7 +75,7 @@ def run_policy(policy: str, region: str, dry_run: str):
             logger.info(git_leaks.scan_repo())
         except Exception as err:
             logger.exception(f'BadCredentialsException : {err}')
-    elif policy == 'ec2_idle' or policy == 'ebs_unattached':  # default policy of cloud custodian - yaml file
+    elif policy == 'ec2_idle' or policy == 'ebs_unattached' or policy == 'ec2_untag':  # default policy of cloud custodian - yaml file
         # default is dry run - change it to custodian dry run format
         if dry_run == 'yes':
             dry_run = '--dryrun'
@@ -91,7 +91,7 @@ def run_policy(policy: str, region: str, dry_run: str):
         else:
             raise Exception(f'Missing Policy name: "{policies_path}/{policy}.yml"')
             logger.exception(f'Missing Policy name: "{policies_path}/{policy}.yml"')
-    else:  # custom policy
+    else:  # local policy
         # default is dry run - change it to custodian dry run format
         if dry_run == 'yes':
             dry_run = '--dryrun'
